Builds the A* matrix
buildAstar(foinew, ldfnew, grainsize, debug)buildAstar takes a matrix representing the file of interest and
a matrix representing the linking data file and creates a matrix that
can then be used to generating linking scores. Reporting frequency as this
occurs can be specified via the nreport option. This is implemented in C++
to provide a speed increase over implementing it directly in the R equivalent.