This function calculates a score from two files, the file of interest (FOI) and linkage data file (LDF).
calcScores(FOI, LDF, missing.value = NA, min.parallelblocksize = 1,
output.varnames = NULL, debug = FALSE)A list containing: An numeric vector of scores, one for
each of the identifiers of interest and a matrix containing A*.
A data.frame object, matrix or
vector to be used as the file of interest. This must contain
only the variables of interest, and these must be in the same order as the LDF.
A data.frame object, matrix or
vector to be used as the linkage data file. This must contain
only the variables of interest, and these must be in the same order as the FOI.
Value used to represent missing data; Defaults to NA
The minimum block size when splitting up the data accross processors. You may wish to change this to optimise the allocation of processors. see (https://rcppcore.github.io/RcppParallel/#tuning).
Labels to apply to function output; Defaults to column names
of the FOI data.frame
Boolean indicating whether to output additional debugging information
Goldstein H., and Charlton, C.M.J., (2017) Centre for Multilevel Modelling, University of Bristol.